@@ -1,6 +1,7 @@
 use v6.c;
 
-use Bailador::Route;
+use Bailador::Route::AutoHead;
+use Bailador::RouteHelper;
 
 role Bailador::Feature::AutoHead {
 
@@ -20,23 +21,25 @@ role Bailador::Feature::AutoHead {
 
             if 'GET' ~~ any( $child-route.method ) && 'HEAD' !~~ any ( $child-route.method ) {
                 # found a route with GET but no HEAD
-                %found-get{ $child-route.path.perl } = $child-route;
+                %found-get{ $child-route.route-spec } = $child-route;
             }
             if 'HEAD' ~~ any( $child-route.method ) && 'GET' !~~ any ( $child-route.method ) {
                 # found a route with HEAD but no GET
-                %found-head{ $child-route.path.perl } = 1;
+                %found-head{ $child-route.route-spec } = 1;
             }
         }
 
         for %found-get.kv -> $key, $orig-route {
             unless %found-head{ $key }:exists {
-                my $code       = sub (|c) {
-                    $orig-route.code.(|c);
+                my $code       = sub (Match $match) {
+                    my $result = $orig-route.execute($match);
+                    # this turns off auto rendering
                     $app.render: "";
+                    # return the old result, because if boolean this is important for route dispatching
+                    return $result;
                 };
-                my $path-str   = $orig-route.path-str;
-                my $path       = $orig-route.path;
-                my $head-route = Bailador::Route.new('HEAD', $path, $code, $path-str);
+                my $path       = $orig-route.url-matcher;
+                my $head-route = Bailador::Route::AutoHead.new( methods => 'HEAD', url-matcher => $path, code => $code);
                 $route.add_route($head-route);
             }
         }
